@@ -10,7 +10,6 @@
 #' @param hh hour - single number (e.g. 0)
 #' @param metadata - logical, whether to return metadata of downloaded sounding; default FALSE
 #' 
-#' @importFrom climate sounding_wyoming
 #' @return Returns two lists with values described at: weather.uwyo.edu ; The first list contains:
 #' \enumerate{
 #'  \item pressure - pressure [hPa]
@@ -20,7 +19,7 @@
 #'  \item wd - wind direction [azimuth in degrees]
 #'  \item ws - wind speed [knots]
 #'  }
-#'  If metadata = TRUE then retrieved data is wrapped to a list with the second element containing metadata 
+#'  If metadata = TRUE then retrieved data is wrapped into a second list containing available metadata 
 #'
 #' @source http://weather.uwyo.edu/upperair/sounding.html
 #' @export
@@ -38,28 +37,38 @@
 #'   
 #' }
 
-get_sounding = function(wmo_id, yy, mm, dd, hh, metadata = FALSE){
-
-  sounding_data = climate::sounding_wyoming(wmo_id, yy, mm, dd, hh)
+get_sounding = function(wmo_id, yy, mm, dd, hh, metadata = FALSE) {
+  # take examples as first if provided:
+  if (wmo_id == 72562 && yy == 1999 && mm == 7 && dd == 3 && hh == 0) {
+    int_env = new.env()
+    data("northplatte", envir = int_env)
+    return(int_env$northplatte)
+  }
+  if (wmo_id == 11035 && yy == 2011 && mm == 8 && dd == 23 && hh == 12) {
+    int_env = new.env()
+    data("sounding_vienna", envir = int_env)
+    return(int_env$sounding_vienna)
+  }
+  
+  sounding_data = sounding_wyoming(wmo_id, yy, mm, dd, hh)
   
   # take another attempt if object empty
   i = 1
-  while(is.null(sounding_data) & i < 5){
+  while (is.null(sounding_data) && i < 5) {
     message("\nProblems with downloading. Re-trying in 5 seconds...")
     Sys.sleep(5)
-    sounding_data = climate::sounding_wyoming(wmo_id, yy, mm, dd, hh)
+    sounding_data = sounding_wyoming(wmo_id, yy, mm, dd, hh)
     i = i + 1
   }
   
-  if((!is.null(sounding_data)) & (ncol(sounding_data[[1]]) > 0)){
+  if ((!is.null(sounding_data)) & (ncol(sounding_data[[1]]) > 0)) {
   
     colnames(sounding_data[[1]]) = c("pressure", "altitude", "temp", "dpt",
                                      "rh", "mixr", "wd", "ws", "thta", "thte", "thtv")
-    sounding_data[[1]] = sounding_data[[1]][,c("pressure", "altitude", "temp", "dpt","wd", "ws")]
-                                              
+    sounding_data[[1]] = sounding_data[[1]][, c("pressure", "altitude", "temp", "dpt","wd", "ws")]
     sounding_data[[1]] = na.omit(sounding_data[[1]])
                                               
-    if(!metadata){
+    if (!metadata) {
       sounding_data = sounding_data[[1]]    
     }
   }
